@@ -251,6 +251,7 @@ int main(int argc, const char **argv)
 	RelaySW = FALSE;
 	respFlags = RespNULL;
 	repeater_mode = 0;
+	COS_On = FALSE;
 
 	config (argc, (char **)argv);
 
@@ -284,11 +285,6 @@ int main(int argc, const char **argv)
 
 	rf_qid = mq_open ("/dstar_rf", O_RDWR | O_CREAT, 
 		S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH, &rf_mattr);
-printf ("debug %d\n",rf_qid);
-if (rf_qid == -1)
-{
-	printf ("open error on mq_open %d\n",errno);
-}
 
         /* define mq attribute */
         inet_mattr.mq_flags = O_NONBLOCK;
